C:\b\abs_b7f5go6r0j\croot\y-py_1683662173571\work\target\release\deps\unicode_ident-b5c2061da4b39d3b.rmeta: C:\b\abs_b7f5go6r0j\croot\y-py_1683662173571\_build_env\.cargo.win\registry\src\github.com-1ecc6299db9ec823\unicode-ident-1.0.6\src\lib.rs C:\b\abs_b7f5go6r0j\croot\y-py_1683662173571\_build_env\.cargo.win\registry\src\github.com-1ecc6299db9ec823\unicode-ident-1.0.6\src\tables.rs

C:\b\abs_b7f5go6r0j\croot\y-py_1683662173571\work\target\release\deps\libunicode_ident-b5c2061da4b39d3b.rlib: C:\b\abs_b7f5go6r0j\croot\y-py_1683662173571\_build_env\.cargo.win\registry\src\github.com-1ecc6299db9ec823\unicode-ident-1.0.6\src\lib.rs C:\b\abs_b7f5go6r0j\croot\y-py_1683662173571\_build_env\.cargo.win\registry\src\github.com-1ecc6299db9ec823\unicode-ident-1.0.6\src\tables.rs

C:\b\abs_b7f5go6r0j\croot\y-py_1683662173571\work\target\release\deps\unicode_ident-b5c2061da4b39d3b.d: C:\b\abs_b7f5go6r0j\croot\y-py_1683662173571\_build_env\.cargo.win\registry\src\github.com-1ecc6299db9ec823\unicode-ident-1.0.6\src\lib.rs C:\b\abs_b7f5go6r0j\croot\y-py_1683662173571\_build_env\.cargo.win\registry\src\github.com-1ecc6299db9ec823\unicode-ident-1.0.6\src\tables.rs

C:\b\abs_b7f5go6r0j\croot\y-py_1683662173571\_build_env\.cargo.win\registry\src\github.com-1ecc6299db9ec823\unicode-ident-1.0.6\src\lib.rs:
C:\b\abs_b7f5go6r0j\croot\y-py_1683662173571\_build_env\.cargo.win\registry\src\github.com-1ecc6299db9ec823\unicode-ident-1.0.6\src\tables.rs:
