C:\b\abs_b7f5go6r0j\croot\y-py_1683662173571\work\target\release\build\quote-34fb2d08cdd2eba8\build_script_build-34fb2d08cdd2eba8.exe: C:\b\abs_b7f5go6r0j\croot\y-py_1683662173571\_build_env\.cargo.win\registry\src\github.com-1ecc6299db9ec823\quote-1.0.23\build.rs

C:\b\abs_b7f5go6r0j\croot\y-py_1683662173571\work\target\release\build\quote-34fb2d08cdd2eba8\build_script_build-34fb2d08cdd2eba8.d: C:\b\abs_b7f5go6r0j\croot\y-py_1683662173571\_build_env\.cargo.win\registry\src\github.com-1ecc6299db9ec823\quote-1.0.23\build.rs

C:\b\abs_b7f5go6r0j\croot\y-py_1683662173571\_build_env\.cargo.win\registry\src\github.com-1ecc6299db9ec823\quote-1.0.23\build.rs:
