C:\b\abs_b7f5go6r0j\croot\y-py_1683662173571\work\target\release\build\proc-macro2-08a20a9aeedaa04a\build_script_build-08a20a9aeedaa04a.exe: C:\b\abs_b7f5go6r0j\croot\y-py_1683662173571\_build_env\.cargo.win\registry\src\github.com-1ecc6299db9ec823\proc-macro2-1.0.51\build.rs

C:\b\abs_b7f5go6r0j\croot\y-py_1683662173571\work\target\release\build\proc-macro2-08a20a9aeedaa04a\build_script_build-08a20a9aeedaa04a.d: C:\b\abs_b7f5go6r0j\croot\y-py_1683662173571\_build_env\.cargo.win\registry\src\github.com-1ecc6299db9ec823\proc-macro2-1.0.51\build.rs

C:\b\abs_b7f5go6r0j\croot\y-py_1683662173571\_build_env\.cargo.win\registry\src\github.com-1ecc6299db9ec823\proc-macro2-1.0.51\build.rs:
