C:\b\abs_b7f5go6r0j\croot\y-py_1683662173571\work\target\release\build\thiserror-49a944004d29df1e\build_script_build-49a944004d29df1e.exe: C:\b\abs_b7f5go6r0j\croot\y-py_1683662173571\_build_env\.cargo.win\registry\src\github.com-1ecc6299db9ec823\thiserror-1.0.38\build.rs

C:\b\abs_b7f5go6r0j\croot\y-py_1683662173571\work\target\release\build\thiserror-49a944004d29df1e\build_script_build-49a944004d29df1e.d: C:\b\abs_b7f5go6r0j\croot\y-py_1683662173571\_build_env\.cargo.win\registry\src\github.com-1ecc6299db9ec823\thiserror-1.0.38\build.rs

C:\b\abs_b7f5go6r0j\croot\y-py_1683662173571\_build_env\.cargo.win\registry\src\github.com-1ecc6299db9ec823\thiserror-1.0.38\build.rs:
