C:\b\abs_b7f5go6r0j\croot\y-py_1683662173571\work\target\release\build\windows_x86_64_msvc-06687a660aad00fe\build_script_build-06687a660aad00fe.exe: C:\b\abs_b7f5go6r0j\croot\y-py_1683662173571\_build_env\.cargo.win\registry\src\github.com-1ecc6299db9ec823\windows_x86_64_msvc-0.42.1\build.rs

C:\b\abs_b7f5go6r0j\croot\y-py_1683662173571\work\target\release\build\windows_x86_64_msvc-06687a660aad00fe\build_script_build-06687a660aad00fe.d: C:\b\abs_b7f5go6r0j\croot\y-py_1683662173571\_build_env\.cargo.win\registry\src\github.com-1ecc6299db9ec823\windows_x86_64_msvc-0.42.1\build.rs

C:\b\abs_b7f5go6r0j\croot\y-py_1683662173571\_build_env\.cargo.win\registry\src\github.com-1ecc6299db9ec823\windows_x86_64_msvc-0.42.1\build.rs:
