C:\b\abs_b7f5go6r0j\croot\y-py_1683662173571\work\target\release\deps\y_py.dll: src\lib.rs src\shared_types.rs src\type_conversions.rs src\y_array.rs src\y_doc.rs src\y_map.rs src\y_text.rs src\y_transaction.rs src\y_xml.rs

C:\b\abs_b7f5go6r0j\croot\y-py_1683662173571\work\target\release\deps\y_py.d: src\lib.rs src\shared_types.rs src\type_conversions.rs src\y_array.rs src\y_doc.rs src\y_map.rs src\y_text.rs src\y_transaction.rs src\y_xml.rs

src\lib.rs:
src\shared_types.rs:
src\type_conversions.rs:
src\y_array.rs:
src\y_doc.rs:
src\y_map.rs:
src\y_text.rs:
src\y_transaction.rs:
src\y_xml.rs:

# env-dep:CARGO_PKG_VERSION=0.5.9
