C:\b\abs_b7f5go6r0j\croot\y-py_1683662173571\work\target\release\build\libc-e6614d78b0e35bb0\build_script_build-e6614d78b0e35bb0.exe: C:\b\abs_b7f5go6r0j\croot\y-py_1683662173571\_build_env\.cargo.win\registry\src\github.com-1ecc6299db9ec823\libc-0.2.139\build.rs

C:\b\abs_b7f5go6r0j\croot\y-py_1683662173571\work\target\release\build\libc-e6614d78b0e35bb0\build_script_build-e6614d78b0e35bb0.d: C:\b\abs_b7f5go6r0j\croot\y-py_1683662173571\_build_env\.cargo.win\registry\src\github.com-1ecc6299db9ec823\libc-0.2.139\build.rs

C:\b\abs_b7f5go6r0j\croot\y-py_1683662173571\_build_env\.cargo.win\registry\src\github.com-1ecc6299db9ec823\libc-0.2.139\build.rs:
