C:\b\abs_b7f5go6r0j\croot\y-py_1683662173571\work\target\release\build\lock_api-8e4896f5484b0cc6\build_script_build-8e4896f5484b0cc6.exe: C:\b\abs_b7f5go6r0j\croot\y-py_1683662173571\_build_env\.cargo.win\registry\src\github.com-1ecc6299db9ec823\lock_api-0.4.9\build.rs

C:\b\abs_b7f5go6r0j\croot\y-py_1683662173571\work\target\release\build\lock_api-8e4896f5484b0cc6\build_script_build-8e4896f5484b0cc6.d: C:\b\abs_b7f5go6r0j\croot\y-py_1683662173571\_build_env\.cargo.win\registry\src\github.com-1ecc6299db9ec823\lock_api-0.4.9\build.rs

C:\b\abs_b7f5go6r0j\croot\y-py_1683662173571\_build_env\.cargo.win\registry\src\github.com-1ecc6299db9ec823\lock_api-0.4.9\build.rs:
