IF "%CONDA_BUILD%" == "" (
    call C:\b\abs_b7f5go6r0j\croot\y-py_1683662173571\work\build_env_setup.bat
)
REM ===== end generated header =====
C:\\b\\abs_b7f5go6r0j\\croot\\y-py_1683662173571\\_h_env\\python.exe -m pip install --no-deps --no-build-isolation . -vv
cargo-bundle-licenses --format yaml --output THIRDPARTY.yml