C:\b\abs_b7f5go6r0j\croot\y-py_1683662173571\work\target\release\build\parking_lot_core-8f22565f86ae835a\build_script_build-8f22565f86ae835a.exe: C:\b\abs_b7f5go6r0j\croot\y-py_1683662173571\_build_env\.cargo.win\registry\src\github.com-1ecc6299db9ec823\parking_lot_core-0.9.7\build.rs

C:\b\abs_b7f5go6r0j\croot\y-py_1683662173571\work\target\release\build\parking_lot_core-8f22565f86ae835a\build_script_build-8f22565f86ae835a.d: C:\b\abs_b7f5go6r0j\croot\y-py_1683662173571\_build_env\.cargo.win\registry\src\github.com-1ecc6299db9ec823\parking_lot_core-0.9.7\build.rs

C:\b\abs_b7f5go6r0j\croot\y-py_1683662173571\_build_env\.cargo.win\registry\src\github.com-1ecc6299db9ec823\parking_lot_core-0.9.7\build.rs:
