@echo on
set "CONDA_BUILD=1"
set "PYTHONNOUSERSITE=1"
set "CONDA_DEFAULT_ENV=C:\b\abs_b7f5go6r0j\croot\y-py_1683662173571\_h_env"
set "ARCH=64"
set "PREFIX=C:\b\abs_b7f5go6r0j\croot\y-py_1683662173571\_h_env"
set "BUILD_PREFIX=C:\b\abs_b7f5go6r0j\croot\y-py_1683662173571\_build_env"
set "SYS_PREFIX=C:\miniconda3"
set "SYS_PYTHON=C:\miniconda3\python.exe"
set "SUBDIR=win-64"
set "build_platform=win-64"
set "SRC_DIR=C:\b\abs_b7f5go6r0j\croot\y-py_1683662173571\work"
set "ROOT=C:\miniconda3"
set "CONDA_PY=38"
set "PY3K=1"
set "PY_VER=3.8"
set "STDLIB_DIR=C:\b\abs_b7f5go6r0j\croot\y-py_1683662173571\_h_env\Lib"
set "SP_DIR=C:\b\abs_b7f5go6r0j\croot\y-py_1683662173571\_h_env\Lib\site-packages"
set "PYTHON=C:\b\abs_b7f5go6r0j\croot\y-py_1683662173571\_h_env\python.exe"
set "NPY_VER=1.16"
set "CONDA_NPY=1.16"
set "NPY_DISTUTILS_APPEND_FLAGS=1"
set "PERL_VER=5.26"
set "CONDA_PERL=5.26"
set "LUA_VER=5"
set "CONDA_LUA=5"
set "R_VER=3.4"
set "CONDA_R=3.4"
set "PKG_NAME=y-py"
set "PKG_VERSION=0.5.9"
set "PKG_BUILDNUM=0"
set "PKG_BUILD_STRING=placeholder"
set "PKG_HASH=1234567"
set "RECIPE_DIR=C:\b\abs_b7f5go6r0j\clone\recipe"
set "CPU_COUNT=4"
set "LANG=en_US.UTF-8"
set "SHLIB_EXT=.dll"
set "PATH=C:\b\abs_b7f5go6r0j\croot\y-py_1683662173571\_build_env;C:\b\abs_b7f5go6r0j\croot\y-py_1683662173571\_build_env\Library\mingw-w64\bin;C:\b\abs_b7f5go6r0j\croot\y-py_1683662173571\_build_env\Library\usr\bin;C:\b\abs_b7f5go6r0j\croot\y-py_1683662173571\_build_env\Library\bin;C:\b\abs_b7f5go6r0j\croot\y-py_1683662173571\_build_env\Scripts;C:\b\abs_b7f5go6r0j\croot\y-py_1683662173571\_build_env\bin;C:\b\abs_b7f5go6r0j\croot\y-py_1683662173571\_h_env;C:\b\abs_b7f5go6r0j\croot\y-py_1683662173571\_h_env\Library\mingw-w64\bin;C:\b\abs_b7f5go6r0j\croot\y-py_1683662173571\_h_env\Library\usr\bin;C:\b\abs_b7f5go6r0j\croot\y-py_1683662173571\_h_env\Library\bin;C:\b\abs_b7f5go6r0j\croot\y-py_1683662173571\_h_env\Scripts;C:\b\abs_b7f5go6r0j\croot\y-py_1683662173571\_h_env\bin;C:\cygwin64\usr\local\bin;C:\cygwin64\bin;C:\miniconda3;C:\miniconda3\Library\mingw-w64\bin;C:\miniconda3\Library\usr\bin;C:\miniconda3\Library\bin;C:\miniconda3\Scripts;C:\miniconda3\bin;C:\miniconda3\condabin;C:\Program Files (x86)\Intel\oneAPI\tbb\latest\redist\intel64\vc_mt;C:\Program Files (x86)\Intel\oneAPI\tbb\latest\redist\ia32\vc_mt;C:\Program Files (x86)\Intel\oneAPI\mpi\latest\bin;C:\Program Files (x86)\Intel\oneAPI\mpi\latest\bin\release;C:\Program Files (x86)\Intel\oneAPI\mpi\latest\libfabric\bin;C:\Program Files (x86)\Intel\oneAPI\mpi\latest\libfabric\bin\utils;C:\Program Files (x86)\Intel\oneAPI\compiler\latest\windows\redist\intel64_win\compiler;C:\Program Files (x86)\Intel\oneAPI\compiler\latest\windows\redist\ia32_win\compiler;C:\Windows\system32;C:\Windows;C:\Windows\System32\Wbem;C:\Windows\System32\WindowsPowerShell\v1.0;C:\Windows\System32\OpenSSH;C:\Program Files\Amazon\cfn-bootstrap;C:\ProgramData\chocolatey\bin;C:\Program Files\Amazon\AWSCLIV2;C:\Program Files\OpenSSH-Win64;C:\Users\builder-admin\AppData\Local\Microsoft\WindowsApps"
set "SCRIPTS=C:\b\abs_b7f5go6r0j\croot\y-py_1683662173571\_h_env\Scripts"
set "LIBRARY_PREFIX=C:\b\abs_b7f5go6r0j\croot\y-py_1683662173571\_h_env\Library"
set "LIBRARY_BIN=C:\b\abs_b7f5go6r0j\croot\y-py_1683662173571\_h_env\Library\bin"
set "LIBRARY_INC=C:\b\abs_b7f5go6r0j\croot\y-py_1683662173571\_h_env\Library\include"
set "LIBRARY_LIB=C:\b\abs_b7f5go6r0j\croot\y-py_1683662173571\_h_env\Library\lib"
set "CYGWIN_PREFIX=/cygdrive/c/b/abs_b7f5go6r0j/croot/y-py_1683662173571/_h_env"
set "ALLUSERSPROFILE=C:\ProgramData"
set "APPDATA=C:\Users\builder-admin\AppData\Roaming"
set "CommonProgramFiles=C:\Program Files\Common Files"
set "CommonProgramFiles(x86)=C:\Program Files (x86)\Common Files"
set "CommonProgramW6432=C:\Program Files\Common Files"
set "COMPUTERNAME=EC2AMAZ-OVE00H3"
set "ComSpec=C:\Windows\system32\cmd.exe"
set "LOCALAPPDATA=C:\Users\builder-admin\AppData\Local"
set "NUMBER_OF_PROCESSORS=4"
set "PATHEXT=.COM;.EXE;.BAT;.CMD;.VBS;.VBE;.JS;.JSE;.WSF;.WSH;.MSC;.CPL"
set "ProgramData=C:\ProgramData"
set "ProgramFiles=C:\Program Files"
set "ProgramFiles(x86)=C:\Program Files (x86)"
set "ProgramW6432=C:\Program Files"
set "PSModulePath=C:\Users\builder-admin\Documents\WindowsPowerShell\Modules;C:\Program Files\WindowsPowerShell\Modules;C:\Windows\system32\WindowsPowerShell\v1.0\Modules;C:\Program Files (x86)\AWS Tools\PowerShell\"
set "PUBLIC=C:\Users\Public"
set "SystemDrive=C:"
set "SystemRoot=C:\Windows"
set "TEMP=C:\cygwin64\tmp"
set "TMP=C:\cygwin64\tmp"
set "USERDOMAIN=EC2AMAZ-OVE00H3"
set "USERNAME=builder-admin"
set "USERPROFILE=C:\Users\builder-admin"
set "windir=C:\Windows"
set "PROCESSOR_ARCHITECTURE=AMD64"
set "PROCESSOR_IDENTIFIER=Intel64 Family 6 Model 85 Stepping 7, GenuineIntel"
set "BUILD=amd64-pc-windows-19.0.0"
set "VS2017INSTALLDIR=C:\Program Files (x86)\Microsoft Visual Studio\2017\BuildTools"
set "VS2019INSTALLDIR=C:\Program Files (x86)\Microsoft Visual Studio\2019\BuildTools"
set "ignore_build_only_deps={'python', 'numpy'}"
set "extend_keys={'ignore_build_only_deps', 'extend_keys', 'pin_run_as_build', 'ignore_version'}"
set "pin_run_as_build=OrderedDict([('python', OrderedDict([('min_pin', 'x.x'), ('max_pin', 'x.x')])), ('r-base', OrderedDict([('min_pin', 'x.x'), ('max_pin', 'x.x')])), ('libboost', {'max_pin': 'x.x.x'})])"
set "zip_keys=[['python', 'numpy']]"
set "fontconfig=2.14"
set "cairo=1.16"
set "glib=2"
set "libxslt=1.1"
set "vc=14"
set "libtiff=4.1"
set "libgsasl=1.8"
set "libdap4=3.19"
set "clang_variant=clang"
set "cyrus_sasl=2.1.26"
set "proj=6.2.1"
set "rust_compiler_version=1.64.0"
set "giflib=5"
set "VERBOSE_AT=V=1"
set "gstreamer=1.18"
set "libprotobuf=3.20.3"
set "gmp=6.1"
set "cross_compiler_target_platform=win-64"
set "xz=5"
set "libgdal=3.0"
set "openjpeg=2.3"
set "python_impl=cpython"
set "c_compiler=vs2017"
set "r_version=3.5.0"
set "libwebp=1.2.4"
set "geos=3.8.0"
set "blas_impl=mkl"
set "llvm_variant=llvm"
set "r_base=3.4"
set "freetype=2.10"
set "libgd=2.3.3"
set "openblas=0.3.21"
set "dbus=1"
set "proj4=5.2.0"
set "icu=58"
set "cpu_optimization_target=nocona"
set "VERBOSE_CM=VERBOSE=1"
set "mpfr=4"
set "jpeg=9"
set "serf=1.3.9"
set "target_platform=win-64"
set "g2clib=1.6"
set "mkl=2023.*"
set "fortran_compiler=intel-fortran"
set "libnetcdf=4.8"
set "openssl=1.1.1"
set "channel_targets=defaults"
set "pixman=0.40"
set "libpng=1.6"
set "cran_mirror=https://mran.microsoft.com/snapshot/2018-01-01"
set "hdfeos2=2.20"
set "apr=1.6.3"
set "lzo=2"
set "hdf5=1.10.6"
set "readline=8.0"
set "r_implementation=r-base"
set "m2w64_fortran_compiler=m2w64-toolchain"
set "hdf4=4.2"
set "gst_plugins_base=1.18"
set "libkml=1.3"
set "boost=1.73"
set "boost_cpp=1.73"
set "gnu=2.12.2"
set "hdfeos5=5.1"
set "sqlite=3"
set "rust_compiler=rust"
set "tk=8.6"
set "fortran_compiler_version=2022.1.0"
set "cxx_compiler=vs2017"
set "m2w64_cxx_compiler=m2w64-toolchain"
set "bzip2=1.0"
set "zstd=1.5.2"
set "zlib=1.2"
set "m2w64_c_compiler=m2w64-toolchain"
set "expat=2"
set "harfbuzz=4.3.0"
set "python_implementation=cpython"
set "libffi=3.4"
set "libxml2=2.10"
set "CONDA_BUILD_STATE=BUILD"
set "PIP_NO_BUILD_ISOLATION=False"
set "PIP_NO_DEPENDENCIES=True"
set "PIP_IGNORE_INSTALLED=True"
set "PIP_CACHE_DIR=C:\b\abs_b7f5go6r0j\croot\y-py_1683662173571\pip_cache"
set "PIP_NO_INDEX=True"
@echo on
set "INCLUDE=C:\b\abs_b7f5go6r0j\croot\y-py_1683662173571\_h_env\Library\include;%INCLUDE%"
set "LIB=C:\b\abs_b7f5go6r0j\croot\y-py_1683662173571\_h_env\Library\lib;%LIB%"
call "C:\miniconda3\Scripts\..\condabin\conda_hook.bat"
call "C:\miniconda3\Scripts\..\condabin\conda.bat" activate "C:\b\abs_b7f5go6r0j\croot\y-py_1683662173571\_h_env"
call "C:\miniconda3\Scripts\..\condabin\conda.bat" activate --stack "C:\b\abs_b7f5go6r0j\croot\y-py_1683662173571\_build_env"
